@@ -122,8 +122,13 @@ def get_path(filename: str) -> Path:
     images = Path(
         BuiltIn().get_variable_value('${SUITE SOURCE}')).parent.parent / 'images' / filename
     downloads = Path(get_downloads_dir()) / filename
-    paths = [downloads, files, images]
+    exec_dir = BuiltIn().get_variable_value('${EXECDIR}')
+    files_exec_dir = Path(f"{get_exec_subdir(exec_dir, 'files')}/{filename}")
+    images_exec_dir = Path(f"{get_exec_subdir(exec_dir, 'images')}/{filename}")
+    paths = [downloads, files, images, files_exec_dir, images_exec_dir]
+
     for path in paths:
+        logger.info(path, also_console=True)
         if path.exists():
             logger.debug(path)
             return path
@@ -134,3 +139,28 @@ def get_path(filename: str) -> Path:
     except TypeError as e:
         raise QWebFileNotFoundError(
             'File not found from default folders. Set variable for base image path') from e
+
+
+def get_exec_subdir(base_path: str, target_dir: str) -> str:
+    """Finds a "special" subdirectory under execution dir.
+
+    Returns full path to special dir if found.
+    Returns base_path if special dir is not found.
+
+    Parameters
+    ----------
+    base_path : str
+    target_dir: str
+
+    Returns
+    -------
+    str
+    """
+    # pylint: disable=unused-variable
+    d = None
+    for root, dirs, files in os.walk(base_path):
+        for d in dirs:
+            if d.lower() == target_dir:
+                return os.path.join(root, d)
+
+    return os.path.join(base_path, target_dir)
