@@ -127,7 +127,9 @@ def get_closest_element(locator_element: WebElement,
     return closest_element
 
 
-def get_unique_element_by_xpath(xpath: str, **kwargs: Any) -> WebElement:
+def get_unique_element_by_xpath(xpath: str,
+                                index: Union[str, int] = 0,
+                                **kwargs: Any) -> WebElement:
     """Get element if it is needed to be unique.
 
     One use case is that when xpath is written in the test script with
@@ -137,19 +139,25 @@ def get_unique_element_by_xpath(xpath: str, **kwargs: Any) -> WebElement:
     ----------
     xpath : str
         XPath string. If 'xpath=' -prefix is used, it will be omitted.
+    index : int (Optional)
+        Index of element to return if there are multiple.
     """
     if xpath.startswith("xpath="):
         xpath = xpath.split("=", 1)[1]
+    try:
+        index = int(index)
+    except ValueError:
+        index = 0
     elements = get_webelements_in_active_area(xpath, **kwargs)
     # pylint: disable=no-else-return
-    if elements and len(elements) == 1:
+    if elements and len(elements) > index:
         if CONFIG['SearchMode']:
-            draw_borders(elements[0])
-        return elements[0]
+            draw_borders(elements[index])
+        return elements[index]
     elif not elements:
         raise QWebElementNotFoundError('XPath {} did not find any elements'.format(xpath))
-    raise QWebValueError('XPath {} matched {} elements. Needs to be unique'.format(
-        xpath, len(elements)))
+    raise QWebValueError(f'XPath {xpath} matched {len(elements)} elements.'
+                         f'Used index was {index+1}')
 
 
 @frame.all_frames
@@ -177,6 +185,7 @@ def get_webelements(xpath: str, **kwargs: Any) -> list[WebElement]:
     web_elements = driver.find_elements(By.XPATH, xpath)
     logger.trace("XPath {} matched {} WebElements".format(xpath, len(web_elements)))
     web_elements = get_visible_elements_from_elements(web_elements, **kwargs)
+
     return web_elements
 
 
@@ -597,15 +606,18 @@ def get_elements_by_attributes(
             elements,
             locator.replace("\'", "\\'"),  # type: ignore[union-attr]
             partial)
+
         logger.debug('attrfunc found full matches: {}, partial matches: {}'.format(
             matches.get('full'), matches.get('partial')))
         full_matches, partial_matches = matches.get('full', []), matches.get('partial', [])
     except (WebDriverException, JavascriptException, AttributeError) as e:
         logger.debug('Got exception from get elements by attributes: {}'.format(e))
         full_matches, partial_matches = [], []
+
     if 'element_kw' not in kwargs:
         return full_matches, partial_matches
     web_elements = full_matches + partial_matches
+
     if web_elements:
         if CONFIG['SearchMode']:
             draw_borders(web_elements)
@@ -692,3 +704,13 @@ def get_element_to_click_from_list(active_list: list[WebElement], index: int,
     else:
         element = active_list[index]
     return element
+
+
+def get_element_by_index(elements: list[WebElement], index: Union[str, int]) -> WebElement:
+    if str(index).isdigit():
+        try:
+            return elements[int(index) - 1]
+        except IndexError as ie:
+            raise QWebValueError(f'Only "{len(elements)}" elements found.'
+                                 f'Used index was "{index}"') from ie
+    raise ValueError(f'Index should be numeric. Used index was: "{index}"')
