@@ -21,12 +21,12 @@ from selenium.webdriver.remote.webelement import WebElement
 from robot.api import logger
 from QWeb.internal.exceptions import QWebElementNotFoundError, \
     QWebInstanceDoesNotExistError
-from QWeb.internal import element, text
+from QWeb.internal import element, text, frame, javascript
 from QWeb.internal.table import Table
 from QWeb.internal.config_defaults import CONFIG
 
 
-def get_input_element_by_locator(locator: str, anchor: str, **kwargs) -> WebElement:
+def get_input_element_by_locator(locator: str, anchor: Union[str, int], **kwargs) -> WebElement:
     """Find input element.
 
     Parameters
@@ -46,12 +46,12 @@ def get_input_element_by_locator(locator: str, anchor: str, **kwargs) -> WebElem
             xpath = locator.split("=", 1)[1]
         else:
             xpath = locator
-        input_element = element.get_unique_element_by_xpath(xpath, **kwargs)
+        input_element = element.get_unique_element_by_xpath(xpath, index=anchor, **kwargs)
     else:  # Search using text
         input_xpath = CONFIG["MatchingInputElement"].format(locator)
         input_elements = element.get_webelements_in_active_area(input_xpath, **kwargs)
         if not input_elements:  # Find input element using locator
-            locator_element = text.get_text_using_anchor(locator, anchor, **kwargs)
+            locator_element = text.get_text_using_anchor(locator, str(anchor), **kwargs)
             input_elements = _get_all_input_elements()
 
             shadow_dom = CONFIG['ShadowDOM']
@@ -127,13 +127,13 @@ def get_input_elements_from_all_documents(
         raise QWebElementNotFoundError('No matching table input found')
     css_selector = CONFIG["CssSelectors"]
     if not css_selector or locator.startswith('xpath=') or locator.startswith('//'):
-        input_element = get_input_element_by_locator(locator, anchor, **kwargs)
+        input_element = get_input_element_by_locator(locator, index, **kwargs)
     else:
         logger.debug('Uses CSS-selectors to locate element')
         input_element = get_input_element_by_css_selector(locator, anchor, int(index), enable_check,
                                                           **kwargs)
         if not input_element:
-            input_element = get_input_element_by_locator(locator, anchor, **kwargs)
+            input_element = get_input_element_by_locator(locator, index, **kwargs)
     if input_element:
         if CONFIG['SearchMode']:
             element.draw_borders(input_element)
@@ -180,7 +180,8 @@ def get_input_element_by_css_selector(locator: str,
         except ValueError:
             logger.debug('locator was text')
     if 'qweb_old' not in kwargs:
-        full_matches, partial_matches = element.get_elements_by_css(locator, **kwargs)
+        full_matches, partial_matches = get_input_elements_by_css(locator, **kwargs)
+
         if full_matches:
             input_element = element.get_visible_elements_from_elements(full_matches, **kwargs)
             if input_element and str(anchor) == '1':
@@ -203,3 +204,29 @@ def get_input_element_by_css_selector(locator: str,
             if element.is_enabled(visibles[index]) or enable_check is True:
                 return visibles[index]
     return None
+
+
+@frame.all_frames
+def get_inputs_including_shadow_dom(locator: str, **kwargs) -> list[WebElement]:
+    web_elements = element.get_visible_elements_from_elements(
+        javascript.get_all_input_elements_from_shadow_dom(), **kwargs)
+
+    matches = javascript.get_by_attributes(web_elements, locator, False)
+    full, partial = matches.get('full', []), matches.get('partial', [])
+    shadow_elements = full + partial
+    if shadow_elements:
+        logger.debug(f'Found {len(shadow_elements)} inputs when extending search to shadow dom')
+    return shadow_elements
+
+
+def get_input_elements_by_css(locator: str, **kwargs):
+    full_matches, partial_matches = element.get_elements_by_css(locator, **kwargs)
+
+    shadow_dom = CONFIG['ShadowDOM']
+    if shadow_dom:
+        shadow_elements = get_inputs_including_shadow_dom(locator, **kwargs)
+        #  remove duplicates (normal search and including shadow search)
+        for el in shadow_elements:
+            if full_matches is not None and el not in list(full_matches):
+                full_matches.append(el)  # type: ignore[union-attr]
+    return full_matches, partial_matches
