@@ -157,6 +157,9 @@ def get_by_attributes(elements: list[WebElement], locator: str,
             var part = [];
             for (var i = 0; i < elems.length; i++) {
                var attrs = elems[i].attributes;
+               if (attrs == null){
+                continue;
+               }
                for (var j = 0; j < attrs.length; j++) {
                     if (attrs[j].value.trim() == locator) {
                         full.push(elems[i]);
@@ -456,9 +459,10 @@ def get_text_elements_from_shadow_dom(locator: str, partial: bool) -> list[WebEl
     js = get_recursive_walk() + """
     function find_text_from_shadow_dom(text, partial){
         var results = [];
+        var unsupported_tags = ["script", "#document-fragment"]
         var elem = recursiveWalk(document.body, function(node) {
         //if (node.innerText == text) {
-        if (node.textContent.includes(text)) {
+        if (node.textContent.includes(text) && !unsupported_tags.includes(node.nodeName.toLowerCase())) {
             nodetext = [].reduce.call(node.childNodes, function(a, b) { return a + (b.nodeType === 3 ? b.textContent.trim() : ''); }, '');
             if (nodetext == text) {
                 results.push(node);
@@ -483,7 +487,7 @@ def get_all_input_elements_from_shadow_dom() -> list[WebElement]:
     function find_all_input_elements_from_shadow_dom(){
         var results = [];
         var elem = recursiveWalk(document.body, function(node) {
-            if (node.tagName == "INPUT") {
+            if (node.tagName == "INPUT" || node.tagName == "TEXTAREA") {
                     results.push(node);
             }
 
@@ -499,7 +503,7 @@ def get_item_elements_from_shadow_dom(tag: str) -> list[WebElement]:
     js = get_recursive_walk() + """
     function find_item_elements_from_shadow_dom(tag){
         var results = [];
-        var supported_tags = tag === null ? ["A", "SPAN", "IMG", "LI", "H1", "H2", "H3", "H4", "H5", "H6", "DIV", "SVG", "P", "BUTTON", "INPUT"] : [tag.toUpperCase()];
+        var supported_tags = tag === null ? ["A", "SPAN", "IMG", "LI", "H1", "H2", "H3", "H4", "H5", "H6", "DIV", "SVG", "P", "BUTTON", "INPUT", "TEXTAREA"] : [tag.toUpperCase()];
         var elem = recursiveWalk(document.body, function(node) {
             if (supported_tags.includes(node.tagName)) {
                     results.push(node);
