@@ -151,6 +151,7 @@ def get_substring(text: str, **kwargs) -> Union[int, float, str]:
     logger.debug('substring start: {}'.format(start))
     logger.debug('substring end: {}'.format(end))
     text = str(text[start:end]).strip().replace('\n', "")
+    text = text.replace('\r', "")
     try:
         if 'int' in kwargs:
             num = float(text.replace(' ', '').replace(',', '.'))
@@ -299,3 +300,22 @@ def get_callable(pw: str) -> Callable[..., Any]:
                 fn = lib.__getattribute__(paceword)
                 return fn
     raise QWebUnexpectedConditionError('Paceword {} not found'.format(pw))
+
+
+def escape_xpath_quotes(text: str) -> str:
+    """Return xpath text with proper quotes"""
+    # both single and double quotes in text
+    if '"' in text and "'" in text:
+        return 'concat(%s)' % ", '\"',".join('"%s"' % x for x in text.split('"'))
+    # only double
+    if '"' in text:
+        return f"'{text}'"
+    return f'"{text}"'
+
+
+def anchor_to_index(anchor: str) -> int:
+    try:
+        index = int(anchor) - 1
+    except ValueError:
+        index = 0
+    return index
